@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-12/Applications/Cxx/gdcmanon.cxx $
+  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-14/Applications/Cxx/gdcmanon.cxx $
 
   Copyright (c) 2006-2009 Mathieu Malaterre
   All rights reserved.
@@ -33,7 +33,7 @@
 static void PrintVersion()
 {
   std::cout << "gdcmanon: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2009-06-12 15:58:39 +0200 (Fri, 12 Jun 2009) $";
+  const char date[] = "$Date: 2009-11-12 13:00:13 +0100 (Thu, 12 Nov 2009) $";
   std::cout << date << std::endl;
 }
 
@@ -56,6 +56,12 @@ static bool AnonymizeOneFileDumb(gdcm::Anonymizer &anon, const char *filename, c
 
   anon.SetFile( file );
 
+  if( empty_tags.empty() && replace_tags.empty() && remove_tags.empty() )
+    {
+    std::cerr << "No operation to be done." << std::endl;
+    return false;
+    }
+
   std::vector<gdcm::Tag>::const_iterator it = empty_tags.begin();
   for(; it != empty_tags.end(); ++it)
     {
@@ -149,6 +155,7 @@ static bool GetRSAKeys(gdcm::CryptographicMessageSyntax &cms, const char *privpa
     {
     if( !cms.ParseKeyFile( privpath ) )
       {
+      std::cerr << "Could not parse Private Key: " << privpath << std::endl;
       return false;
       }
     }
@@ -157,6 +164,7 @@ static bool GetRSAKeys(gdcm::CryptographicMessageSyntax &cms, const char *privpa
     {
     if( !cms.ParseCertificateFile( certpath ) )
       {
+      std::cerr << "Could not parse Certificate Key: " << certpath << std::endl;
       return false;
       }
     }
@@ -507,13 +515,22 @@ int main(int argc, char *argv[])
   // one option only please
   if( deidentify && reidentify )
     {
+    std::cerr << "One option please" << std::endl;
     return 1;
     }
   // dumb mode vs smart mode:
   if( ( deidentify || reidentify ) && dumb_mode )
     {
+    std::cerr << "One option please" << std::endl;
     return 1;
     }
+  if( deidentify || reidentify )
+    {
+#ifndef GDCM_USE_SYSTEM_OPENSSL
+    std::cerr << "OpenSSL was not configured." << std::endl;
+    return 1;
+#endif 
+    }
 
   // by default AES 256
   gdcm::CryptographicMessageSyntax::CipherTypes ciphertype;
