@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-12/Applications/Cxx/gdcmconv.cxx $
+  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-14/Applications/Cxx/gdcmconv.cxx $
 
   Copyright (c) 2006-2009 Mathieu Malaterre
   All rights reserved.
@@ -107,7 +107,7 @@ struct SetSQToUndefined
 void PrintVersion()
 {
   std::cout << "gdcmconv: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2009-06-12 14:38:35 +0200 (Fri, 12 Jun 2009) $";
+  const char date[] = "$Date: 2009-10-24 21:19:36 +0200 (Sat, 24 Oct 2009) $";
   std::cout << date << std::endl;
 }
 
@@ -123,7 +123,7 @@ void PrintLossyWarning()
 void PrintHelp()
 {
   PrintVersion();
-  std::cout << "Usage: gdcmconv [OPTION] -i input.dcm -o output.dcm" << std::endl;
+  std::cout << "Usage: gdcmconv [OPTION] input.dcm output.dcm" << std::endl;
   std::cout << "Convert a DICOM file into another DICOM file.\n";
   std::cout << "Parameter (required):" << std::endl;
   std::cout << "  -i --input      DICOM filename" << std::endl;
