@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-12/Applications/Cxx/gdcmdump.cxx $
+  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-14/Applications/Cxx/gdcmdump.cxx $
 
   Copyright (c) 2006-2009 Mathieu Malaterre
   All rights reserved.
@@ -97,7 +97,8 @@ int PrintASN1(const std::string & filename, bool verbose)
     return 1;
     }
   const gdcm::DataElement &encryptedattributessequence = ds.GetDataElement( tencryptedattributessequence );
-  const gdcm::SequenceOfItems * sqi = encryptedattributessequence.GetSequenceOfItems();
+  //const gdcm::SequenceOfItems * sqi = encryptedattributessequence.GetSequenceOfItems();
+  gdcm::SmartPointer<gdcm::SequenceOfItems> sqi = encryptedattributessequence.GetValueAsSQ();
   if( !sqi->GetNumberOfItems() )
     {
     return 1;
@@ -245,7 +246,7 @@ int PrintCSA(const std::string & filename)
 void PrintVersion()
 {
   std::cout << "gdcmdump: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2009-05-19 15:59:08 +0200 (Tue, 19 May 2009) $";
+  const char date[] = "$Date: 2009-10-24 21:19:36 +0200 (Sat, 24 Oct 2009) $";
   std::cout << date << std::endl;
 }
 
