@@ -292,7 +292,7 @@ std::istream &is = *Stream;
     //is.clear();
     // well not anymore, see special handling of trailing \0 in:
     // basic_unzip_streambuf<charT, traits>::fill_input_buffer(void)
-    return is;
+    return is.good();
     }
 
   try
@@ -304,7 +304,8 @@ std::istream &is = *Stream;
         {
         // There is no such thing as Implicit Big Endian... oh well
         // LIBIDO-16-ACR_NEMA-Volume.dcm
-        F->GetDataSet().Read<ImplicitDataElement,SwapperDoOp>(is);
+        //F->GetDataSet().Read<ImplicitDataElement,SwapperDoOp>(is);
+        throw "Virtual Big Endian Implicit is not defined by DICOM";
         }
       else
         {
@@ -470,6 +471,7 @@ std::istream &is = *Stream;
             }
           catch ( Exception &ex )
             {
+            (void)ex;
             is.clear();
             if( haspreamble )
               {
