@@ -128,7 +128,6 @@ bool PixmapReader::Read()
         std::string sopclassuid_str(
           sopclassuid->GetPointer(),
           sopclassuid->GetLength() );
-        assert( sopclassuid_str.find( ' ' ) == std::string::npos );
         MediaStorage ms2 = MediaStorage::GetMSType(sopclassuid_str.c_str());
         bool isImage2 = MediaStorage::IsImage( ms2 );
         if( isImage2 )
@@ -420,7 +419,8 @@ assert(0);
   else if( false && rootds.FindDataElement( tgeiconimage ) )
     {
     const DataElement &iconimagesq = rootds.GetDataElement( tgeiconimage );
-    const SequenceOfItems* sq = iconimagesq.GetSequenceOfItems();
+    //const SequenceOfItems* sq = iconimagesq.GetSequenceOfItems();
+    SmartPointer<SequenceOfItems> sq = iconimagesq.GetValueAsSQ();
     // Is SQ empty ?
     if( !sq ) return;
     SequenceOfItems::ConstIterator it = sq->Begin();
@@ -513,7 +513,8 @@ assert(0);
   else if( false && rootds.FindDataElement( tgeiconimage2 ) )
     {
     const DataElement &iconimagesq = rootds.GetDataElement( tgeiconimage2 );
-    const SequenceOfItems* sq = iconimagesq.GetSequenceOfItems();
+    //const SequenceOfItems* sq = iconimagesq.GetSequenceOfItems();
+    SmartPointer<SequenceOfItems> sq = iconimagesq.GetValueAsSQ();
     // Is SQ empty ?
     if( !sq ) return;
     SequenceOfItems::ConstIterator it = sq->Begin();
