@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program: GDCM (Grassroots DICOM). A DICOM library
-  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-12/Utilities/VTK/Applications/gdcm2vtk.cxx $
+  Module:  $URL: https://gdcm.svn.sourceforge.net/svnroot/gdcm/tags/gdcm-2-0-14/Utilities/VTK/Applications/gdcm2vtk.cxx $
 
   Copyright (c) 2006-2009 Mathieu Malaterre
   All rights reserved.
@@ -22,6 +22,8 @@
 #include "vtkImageReader2Factory.h"
 #include "vtkImageReader2.h"
 #include "vtkImageData.h"
+#include "vtkMetaImageReader.h"
+#include "vtkMetaImageWriter.h"
 #if VTK_MAJOR_VERSION >= 5 && VTK_MINOR_VERSION > 0
 #include "vtkMINCImageReader.h"
 #include "vtkMINCImageAttributes.h"
@@ -54,7 +56,7 @@
 void PrintVersion()
 {
   std::cout << "gdcm2vtk: gdcm " << gdcm::Version::GetVersion() << " ";
-  const char date[] = "$Date: 2009-06-12 14:38:35 +0200 (Fri, 12 Jun 2009) $";
+  const char date[] = "$Date: 2009-10-24 21:19:36 +0200 (Sat, 24 Oct 2009) $";
   std::cout << date << std::endl;
   //std::cout << "             VTK " << vtkVersion::GetVTKVersion() << std::endl;
   std::cout << "          " << vtkVersion::GetVTKSourceVersion() << std::endl;
@@ -352,7 +354,7 @@ int main(int argc, char *argv[])
       writer->Write();
       return 0;
       }
-    else if(  gdcm::System::StrCaseCmp(outputextension,".vti") == 0  )
+    else if(  gdcm::System::StrCaseCmp(outputextension,".vti") == 0  ) // vtkXMLImageDataWriter::GetDefaultFileExtension()
       {
       vtkXMLImageDataWriter * writer = vtkXMLImageDataWriter::New();
       writer->SetFileName( outfilename );
@@ -361,6 +363,17 @@ int main(int argc, char *argv[])
       writer->Write();
       return 0;
       }
+    else if(  gdcm::System::StrCaseCmp(outputextension,".mha") == 0 ||
+              gdcm::System::StrCaseCmp(outputextension,".mhd") == 0  ) // vtkMetaImageReader::GetFileExtensions()
+      {
+      // Weird, the writer does not offer the same API as the Reader, for instance
+      // One cannot set the patient name to store (see vtkMetaImageReader::GetPatientName ...)
+      vtkMetaImageWriter * writer = vtkMetaImageWriter::New();
+      writer->SetFileName( outfilename );
+      writer->SetInput( imgdata );
+      writer->Write();
+      return 0;
+      }
     }
   // else
 
@@ -520,6 +533,32 @@ int main(int argc, char *argv[])
       reader->SetOrientationType( ORIENTATION_BOTLEFT );
 #endif
       }
+    else if( vtkMetaImageReader *reader = vtkMetaImageReader::SafeDownCast( imgreader ) )
+      {
+//  vtkGetMacro(RescaleSlope, double);
+//  vtkGetMacro(RescaleOffset, double);
+      writer->SetScale( reader->GetRescaleSlope() );
+      writer->SetShift( reader->GetRescaleOffset() );
+//  vtkGetStringMacro(Modality);
+      writer->GetMedicalImageProperties()->SetModality( reader->GetModality() );
+
+//  vtkGetStringMacro(DistanceUnits);
+  // -> this one is insane, the default behavior is 'um' . What in the world is 'um' unit ?
+  // I think I should discard any non 'mm' distance unit, simple as that
+
+// The following looks nice from the API, but the VTK implementation only sets them to '?' ... weird
+//  vtkGetMacro(BitsAllocated, int);
+//  vtkGetStringMacro(AnatomicalOrientation);
+//  vtkGetMacro(GantryAngle, double); 
+//  vtkGetStringMacro(PatientName);
+//  vtkGetStringMacro(PatientID);
+//  vtkGetStringMacro(Date);
+//  vtkGetStringMacro(Series);
+//  vtkGetStringMacro(ImageNumber);
+//  vtkGetStringMacro(StudyID);
+//  vtkGetStringMacro(StudyUID);
+//  vtkGetStringMacro(TransferSyntaxUID);
+      }
     }
   // nothing special need to be done for vtkStructuredPointsReader 
 
